// Copyright (c) 1999-2002 David Muse
// See the COPYING file for more information.

	private:
		commandline(const commandline &c);
		commandline	&operator=(const commandline &c);

		commandlineprivate	*pvt;
